@@ -38,20 +38,28 @@ sub awx_configure {
 
 sub wxwidgets_configure_extra_flags {
     my( $self ) = @_;
-    my $extra_flags = '';
-
+    my $extra_flags = $self->notes( 'extraflags' );
+    return $extra_flags if $extra_flags;
+    
+    print qq(Standard Mac Flags in use\n);
+    
+    my $darwinver = 0;
+    if(`uname -r` =~ /^(\d+)\./) {
+        $darwinver = $1;
+    }
+    
     # on Snow Leopard, force wxWidgets 2.8.x builds to be 32-bit;
     if(    $self->notes( 'build_data' )->{data}{version} =~ /^2.8/
-        && `uname -r` =~ /^10\./
+        && $darwinver >= 10
         && `sysctl hw.cpu64bit_capable` =~ /^hw.cpu64bit_capable: 1/ ) {
         print "Forcing wxWidgets build to 32 bit\n";
         $extra_flags = join ' ', map { qq{$_="-arch i386"} }
                                      qw(CFLAGS CXXFLAGS LDFLAGS
                                         OBJCFLAGS OBJCXXFLAGS);
     }
-    # build fix for 2.9.0 on Snow Leopard
-    if(    `uname -r` =~ /^10\./
-        && $self->notes( 'build_data' )->{data}{version} eq '2.9.0' ) {
+    # build fix for 2.9.x on darwin 10 +
+    if( $darwinver >= 10
+        && $self->notes( 'build_data' )->{data}{version} =~ /^2.9/ ) {
         $extra_flags .= ' --with-macosx-version-min=10.5';
     }
 
