@@ -7,6 +7,7 @@ use My::Build::Utility qw(awx_arch_file awx_install_arch_file
 use Config;
 use Fatal qw(open close);
 use Carp qw(cluck);
+use File::Glob qw(bsd_glob);
 
 my $initialized;
 
@@ -15,6 +16,9 @@ sub _init {
     $initialized = 1;
 
     return if Module::Build->current->notes( 'build_wx' );
+    # install_only is set when a wxWidgets build is already configured
+    # with Alien::wxWidgets
+    return if Module::Build->current->notes( 'install_only' );
 
     # check for WXDIR and WXWIN environment variables
     unless( exists $ENV{WXDIR} or exists $ENV{WXWIN} ) {
@@ -49,14 +53,15 @@ sub _patch_command {
 sub awx_grep_dlls {
     my( $self, $libdir, $digits, $mono ) = @_;
     my $ret = {};
+    my $ver = $self->_version_2_dec( $self->awx_w32_bakefile_version );
     my $suff = ( $self->awx_unicode ? 'u' : '' ) .
-               ( $self->awx_debug ? 'd' : '' );
+               ( $self->awx_debug && $ver <= 2.009 ? 'd' : '' );
 
     my @dlls = grep { m/${digits}\d*${suff}_/ }
-               glob( File::Spec->catfile( $libdir, '*.dll' ) );
+               bsd_glob( File::Spec->catfile( $libdir, '*.dll' ) );
     my @libs = grep { m/(?:lib)?wx(?:wince|msw|base)[\w\.]+$/ }
                grep { m/${digits}\d*${suff}(_|\.)/ }
-               glob( File::Spec->catfile( $libdir, "*$Config{lib_ext}" ) );
+               bsd_glob( File::Spec->catfile( $libdir, "*$Config{lib_ext}" ) );
 
     foreach my $full ( @dlls, @libs ) {
         my( $name, $type );
@@ -101,15 +106,20 @@ sub awx_configure {
     $config{config}{toolkit} = $self->is_wince ? 'wce' : 'msw';
     $config{shared_library_path} = awx_install_arch_file( $self, "rEpLaCe/lib" );
 
+    $self->awx_w32_find_setup_dir( $self->wx_config( 'cxxflags' ) );
+
+    return %config;
+}
+
+sub awx_w32_find_setup_dir {
+    my( $self, $cxxflags ) = @_;
+
     die "Unable to find setup.h directory"
-      unless $self->wx_config( 'cxxflags' )
-                 =~ m{[/-]I\s*(\S+lib[\\/][\w\\/]+)(?:\s|$)};
+      unless $cxxflags =~ m{[/-]I\s*(\S+lib[\\/][\w\\/]+)(?:\s|$)};
     $self->{awx_setup_dir} = $1;
 
     $self->{awx_data}{version} = $self->awx_w32_bakefile_version
       if -f $self->awx_w32_build_cfg;
-
-    return %config;
 }
 
 sub awx_w32_bakefile_version {
@@ -218,13 +228,7 @@ sub awx_get_package {
         die "Your compiler is not currently supported on Win32"
     };
 
-    if( Module::Build->current->notes( 'build_wx' ) ) {
-        return $package . '_Bakefile';
-    } else {
-        my $mak_env_in =
-          File::Spec->catfile( $ENV{WXDIR}, 'src', 'make.env.in' );
-        return -f $mak_env_in ? $package . '_Tmake' : $package . '_Bakefile';
-    }
+    return $package . '_Bakefile';
 }
 
 # MSLU is default when using Unicode *and* it has not
@@ -259,6 +263,8 @@ sub build_wxwidgets {
     my $dbg = $self->awx_debug   ? 'BUILD=debug' : 'BUILD=release';
     my $opt = join ' ', $uni, $mslu, $dbg, 'SHARED=1';
 
+    $opt .= ' ' . $self->notes( 'extraflags' ) if($self->notes( 'extraflags' ));
+
     chdir File::Spec->catdir( $ENV{WXDIR}, 'build', 'msw' );
     $self->_system( $self->_make_command . ' ' . $opt );
     chdir File::Spec->catdir( $ENV{WXDIR}, 'contrib', 'build', 'stc' );
